pub enum MetadataError {
RankMismatch {
left: usize,
right: usize,
},
IncompatibleDims {
left: usize,
right: usize,
dim: usize,
},
OutOfBounds {
dim: usize,
rank: usize,
},
IncompatibleShapes {
left: Shape,
right: Shape,
},
Invalid {
reason: String,
},
}Expand description
Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Error that can occur when attempting to modify shapes.
Variants
RankMismatch
The operands have different ranks.
IncompatibleDims
A pair of dimensions are incompatible for broadcasting.
OutOfBounds
Invalid dimension specified for the rank.
IncompatibleShapes
A pair of shapes are incompatible for the operation.
Invalid
Invalid shape.